var __accessCheck = (obj, member, msg) => {
  if (!member.has(obj))
    throw TypeError("Cannot " + msg);
};
var __privateGet = (obj, member, getter) => {
  __accessCheck(obj, member, "read from private field");
  return getter ? getter.call(obj) : member.get(obj);
};
var __privateAdd = (obj, member, value) => {
  if (member.has(obj))
    throw TypeError("Cannot add the same private member more than once");
  member instanceof WeakSet ? member.add(obj) : member.set(obj, value);
};
var __privateSet = (obj, member, value, setter) => {
  __accessCheck(obj, member, "write to private field");
  setter ? setter.call(obj, value) : member.set(obj, value);
  return value;
};

// src/index.ts
import { AsyncAdapter as AsyncAdapter2, SyncAdapter as SyncAdapter2 } from "@stenodb/node";
import fp from "fastify-plugin";

// src/plugin.ts
import { AsyncAdapter, NodeProvider, SyncAdapter } from "@stenodb/node";
import { targetConstructorToSchema } from "class-validator-jsonschema";
var _fastify, _options, _provider, _databases;
var _StenoPlugin = class {
  constructor(fastify, options) {
    __privateAdd(this, _fastify, void 0);
    __privateAdd(this, _options, void 0);
    __privateAdd(this, _provider, void 0);
    __privateAdd(this, _databases, void 0);
    __privateSet(this, _fastify, fastify);
    __privateSet(this, _options, options);
    __privateSet(this, _provider, new NodeProvider(options));
    __privateSet(this, _databases, /* @__PURE__ */ new Map());
    __privateGet(this, _fastify).decorate("steno", { get: this.getDatabase.bind(this) });
  }
  static async createInstance(fastify, options, done) {
    const db = new _StenoPlugin(fastify, options);
    await db.registerDatabases();
    done();
    return db;
  }
  async registerDatabases() {
    this.registerEntities();
    for (const adapter of __privateGet(this, _options).adapters) {
      const db = await __privateGet(this, _provider).create(adapter);
      if (adapter instanceof SyncAdapter) {
        db.read();
      } else if (adapter instanceof AsyncAdapter) {
        await db.read();
      } else {
        throw new TypeError("Invalid adapter");
      }
      this.addSchema(adapter.entity);
      __privateGet(this, _databases).set(adapter.fileName, db);
    }
  }
  registerEntities() {
    if (!__privateGet(this, _options).entities)
      return;
    for (const entity of __privateGet(this, _options).entities) {
      this.addSchema(entity);
    }
  }
  addSchema(entity) {
    if (__privateGet(this, _fastify).getSchema(entity.name))
      return;
    const schema = targetConstructorToSchema(
      entity,
      __privateGet(this, _options).entityOptions
    );
    if (!schema.properties)
      return;
    __privateGet(this, _fastify).addSchema({ ...schema, $id: entity.name });
  }
  getDatabase(name) {
    return __privateGet(this, _databases).get(name);
  }
};
var StenoPlugin = _StenoPlugin;
_fastify = new WeakMap();
_options = new WeakMap();
_provider = new WeakMap();
_databases = new WeakMap();

// src/index.ts
var FastifySteno = fp(StenoPlugin.createInstance, {
  name: "@stenodb/fastify",
  fastify: "4.x"
});
var src_default = StenoPlugin.createInstance;
export {
  AsyncAdapter2 as AsyncAdapter,
  FastifySteno,
  SyncAdapter2 as SyncAdapter,
  src_default as default
};
